@@ -5,6 +5,8 @@
 */
 
 #include "confirmaddresscheckjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../confirmaddresscheckjob.h"
 #include <QTest>
 
@@ -26,8 +28,8 @@ void ConfirmAddressCheckJobTest::shouldHaveEmptyResultByDefault()
 void ConfirmAddressCheckJobTest::shouldReturnEmptyResultWhenNoAddress()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.com"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
+    const QStringList domains{u"foo.com"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
     job.setCheckSettings(domains, whiteList, false);
     job.start();
     QVERIFY(job.invalidEmails().isEmpty());
@@ -42,9 +44,9 @@ void ConfirmAddressCheckJobTest::shouldReturnEmptyResultWhenNoAddress()
 void ConfirmAddressCheckJobTest::shouldReturnAllValidEmailsDomain()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.com"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@foo.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.com"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@foo.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, false);
     job.setAddressList(emails);
     job.start();
@@ -56,9 +58,9 @@ void ConfirmAddressCheckJobTest::shouldReturnAllValidEmailsDomain()
 void ConfirmAddressCheckJobTest::shouldReturnAllValidEmailsDomainRejectedDomain()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.com"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@foo.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.com"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@foo.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, true);
     job.setAddressList(emails);
     job.start();
@@ -70,9 +72,9 @@ void ConfirmAddressCheckJobTest::shouldReturnAllValidEmailsDomainRejectedDomain(
 void ConfirmAddressCheckJobTest::shouldReturnAllInValidEmailsDomain()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.fr"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@foo.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.fr"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@foo.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, false);
     job.setAddressList(emails);
     job.start();
@@ -84,9 +86,9 @@ void ConfirmAddressCheckJobTest::shouldReturnAllInValidEmailsDomain()
 void ConfirmAddressCheckJobTest::shouldReturnAllInValidEmailsDomainReject()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.fr"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@foo.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.fr"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@foo.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, true);
     job.setAddressList(emails);
     job.start();
@@ -98,24 +100,24 @@ void ConfirmAddressCheckJobTest::shouldReturnAllInValidEmailsDomainReject()
 void ConfirmAddressCheckJobTest::shouldReturnValidAndInvalid()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.fr"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@bla.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.fr"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@bla.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, false);
     job.setAddressList(emails);
     job.start();
     QVERIFY(!job.invalidEmails().isEmpty());
     QVERIFY(!job.validEmails().isEmpty());
-    QCOMPARE(job.invalidEmails(), QStringList() << QStringLiteral("blabla@foo.com"));
-    QCOMPARE(job.validEmails(), QStringList() << QStringLiteral("toto@bla.com"));
+    QCOMPARE(job.invalidEmails(), QStringList() << u"blabla@foo.com"_s);
+    QCOMPARE(job.validEmails(), QStringList() << u"toto@bla.com"_s);
 }
 
 void ConfirmAddressCheckJobTest::shouldNotDuplicateValue()
 {
     ConfirmAddressCheckJob job;
-    const QStringList domains{QStringLiteral("foo.com"), QStringLiteral("bla.com")};
-    const QStringList whiteList{QStringLiteral("foo@kde.org"), QStringLiteral("bla@kde.org")};
-    const QStringList emails{QStringLiteral("toto@foo.com"), QStringLiteral("blabla@foo.com")};
+    const QStringList domains{u"foo.com"_s, u"bla.com"_s};
+    const QStringList whiteList{u"foo@kde.org"_s, u"bla@kde.org"_s};
+    const QStringList emails{u"toto@foo.com"_s, u"blabla@foo.com"_s};
     job.setCheckSettings(domains, whiteList, false);
     job.setAddressList(QStringList() << emails << emails);
     job.start();
