@@ -8,7 +8,7 @@
 #pragma once
 
 #include <Akonadi/CalendarBase>
-#include <QVector>
+#include <QList>
 
 namespace Akonadi
 {
@@ -22,9 +22,9 @@ public:
     explicit EventModel(QObject *parent = nullptr);
     ~EventModel() override;
 
-    Q_REQUIRED_RESULT QVector<Akonadi::Collection> collections() const;
+    [[nodiscard]] QList<Akonadi::Collection> collections() const;
 
-    Q_REQUIRED_RESULT Akonadi::Collection collection(qint64 id) const;
+    [[nodiscard]] Akonadi::Collection collection(qint64 id) const;
 
 public Q_SLOTS:
     void addCalendar(const Akonadi::Collection &col);
@@ -38,7 +38,7 @@ private:
     void populateCollection(const Akonadi::Collection &col);
     void removeCollection(const Akonadi::Collection &col);
 
-    QVector<Akonadi::Collection> mCols;
+    QList<Akonadi::Collection> mCols;
     Akonadi::Monitor *mMonitor = nullptr;
     QMap<Akonadi::Collection::Id, KJob *> mFetchJobs;
 };
